@@ -46,13 +46,23 @@ from mongoalchemy.fields import ObjectIdField, Field, BadValueException
 
 class DocumentMeta(type):
     def __new__(mcs, classname, bases, class_dict):
+        # Validate Config Options
+        
+        # Create Class
         new_class = type.__new__(mcs, classname, bases, class_dict)
         
+        if new_class.config_extra_fields not in ['error', 'ignore']:
+            raise DocumentException("config_extra_fields must be one of: 'error', 'ignore'")
+
+        
+        # Set up links between fields and the document class
         for name, value in class_dict.iteritems():
             if not isinstance(value, Field):
                 continue
             value._set_name(name)
             value._set_parent(new_class)
+        
+        # Create a query field instance for use in query expressions
         new_class.f = QueryFieldSet(new_class, new_class.get_fields())
         return new_class
 
@@ -76,7 +86,17 @@ class FieldNotRetrieved(DocumentException):
 class Document(object):
     __metaclass__ = DocumentMeta
     
-    _id = ObjectIdField(required=False)
+    mongo_id = ObjectIdField(required=False, db_field='_id')
+    ''' Default field for the mongo object ID (``_id`` in the database). This field
+        is automatically set on objects when they are saved into the database.
+        This field can be overridden in subclasses if the default ID is not
+        acceptable '''
+    
+    config_extra_fields = 'error'
+    ''' Controls the method to use when dealing with fields passed in to the
+        document constructor.  Possible values are 'error' and 'ignore'. Any 
+        fields which couldn't be mapped can be retrieved (and edited) using
+        :func:`~Document.get_extra_fields` '''
     
     def __init__(self, retrieved_fields=None, **kwargs):
         '''
@@ -92,6 +112,8 @@ class Document(object):
         self.partial = retrieved_fields != None
         self.retrieved_fields = self.__normalize(retrieved_fields)
         
+        self.__extra_fields = {}
+        
         cls = self.__class__
                 
         fields = self.get_fields()
@@ -112,10 +134,13 @@ class Document(object):
             
             if hasattr(field, 'default'):
                 setattr(self, name, field.default)
-        
-        for k in kwargs:
-            if k not in fields:
-                raise ExtraValueException(k)
+            
+            for k in kwargs:
+                if k not in fields:
+                    if self.config_extra_fields == 'ignore':
+                        self.__extra_fields[k] = kwargs[k]
+                    else:
+                        raise ExtraValueException(k)
     
     def __setattr__(self, name, value):
         cls = self.__class__
@@ -149,10 +174,16 @@ class Document(object):
         expressions, updates, loading partial documents, and a number of other 
         places.
         
-        .. seealso:: :class:`~mongoalchemy.query.QueryExpression`, :class:`~mongoalchemy.query.Query`
+        .. seealso:: :class:`~mongoalchemy.query_expression.QueryExpression`, :class:`~mongoalchemy.query.Query`
     
     '''
     
+    def get_extra_fields(self):
+        ''' if :attr:`Document.config_extra_fields` is set to 'ignore', this method will return
+            a dictionary of the fields which couldn't be mapped to the document.
+        '''
+        return self.__extra_fields
+    
     @classmethod
     def get_fields(cls):
         '''Returns a dict mapping the names of the fields in a document 
@@ -221,13 +252,15 @@ class Document(object):
         for index in self.get_indexes():
             index.ensure(collection)
         id = collection.save(self.wrap())
-        self._id = id
+        self.mongo_id = id
     
     def wrap(self):
         '''Returns a transformation of this document into a form suitable to 
             be saved into a mongo database.  This is done by using the ``wrap()``
             methods of the underlying fields to set values.'''
         res = {}
+        for k, v in self.__extra_fields.iteritems():
+            res[k] = v
         cls = self.__class__
         for name in dir(cls):
             field = getattr(cls, name)
@@ -268,6 +301,9 @@ class Document(object):
         params = {}
         for k, v in obj.iteritems():
             k = name_reverse.get(k, k)
+            if not hasattr(cls, k) and cls.config_extra_fields:
+                params[str(k)] = v
+                continue
             field = getattr(cls, k)
             if fields != None and isinstance(field, DocumentField):
                 normalized_fields = cls.__normalize(fields)
