@@ -36,11 +36,17 @@ a subclass must implement:
 :func:`~Field.wrap` and :func:`~Field.unwrap` should be inverse operations.  
 In particular, ``field.unwrap(field.wrap(obj))`` == obj should always be true.
 
-* :func:`Field.is_valid_wrap` --- Returns true if calling :func:`~Field.wrap` will \
-    succeed.  This function should be fast, as it will be called whenever a value 
+* :func:`Field.validate_wrap` --- Raises a :class:`BadValueException` if calling :func:`~Field.wrap` will \
+    fail.  This function should be fast, as it will be called whenever a value 
     is set on a document for this type of field.
-* :func:`Field.is_valid_unwrap` --- Returns true if calling :func:`~Field.unwrap` will \
-    succeed.
+* :func:`Field.validate_unwrap` --- Raises a :class:`BadValueException` if calling :func:`~Field.unwrap` will \
+    fail.
+
+To just check whether something is valid for wrapping or unwrapping, each field has a 
+:func:`Field.is_valid_wrap` and an :func:`Field.is_valid_unwrap` function which call 
+their respective validation function, returning True if a 
+:class:`BadValueException` is not raised.
+
 
 The documentation for each :class:`Field` class will largely just be giving the input and
 output types for :func:`~Field.wrap` and :func:`~Field.unwrap`.
@@ -53,14 +59,44 @@ import itertools
 from datetime import datetime
 from pymongo.objectid import ObjectId
 from mongoalchemy.util import UNSET
+import functools
 
+class FieldMeta(type):
+    def __new__(mcs, classname, bases, class_dict):
+        
+        def validation_wrapper(fun):
+            def wrapped(self, value, *args, **kwds):
+                if self._allow_none and value == None:
+                    return
+                return fun(self, value, *args, **kwds)
+            functools.update_wrapper(wrapped, fun, ('__name__', '__doc__'))
+            return wrapped
+        
+        if 'validate_wrap' in class_dict:
+            class_dict['validate_wrap'] = validation_wrapper(class_dict['validate_wrap'])
+        
+        if 'validate_unwrap' in class_dict:
+            class_dict['validate_unwrap'] = validation_wrapper(class_dict['validate_unwrap'])
+        
+        # Create Class
+        return type.__new__(mcs, classname, bases, class_dict)
 
 class Field(object):
-    ''' Field class docs '''
     auto = False
     
-    def __init__(self, required=True, default=UNSET, db_field=None):
+    __metaclass__ = FieldMeta
+    
+    def __init__(self, required=True, default=UNSET, db_field=None, allow_none=False):
+        '''
+        **Parameters**:
+            * required: The field must be passed when constructing a document (optional. default: ``True``)
+            * default:  Default value to use if one is not given (optional.)
+            * db_field: name to use when saving or loading this field from the database \
+                (optional.  default is the name the field is assigned to on a documet)
+            * allow_none: allow ``None`` as a value (optional. default: False)
+        '''
         self.required = required
+        self._allow_none = allow_none
         self.__db_field = db_field
         if default != UNSET:
             self.default = default
