@@ -1,6 +1,6 @@
 from nose.tools import *
 from mongoalchemy.session import Session
-from mongoalchemy.document import Document, Index, DocumentField, MissingValueException
+from mongoalchemy.document import Document, Index, DocumentField, MissingValueException, DocumentException
 from mongoalchemy.fields import *
 from test.util import known_failure
 
@@ -38,7 +38,7 @@ def test_basic():
     s = get_session()
     d = Doc(count=0)
     s.insert(d)
-    assert d._id
+    assert d.mongo_id
 
 def test_basic2():
     class Doc(Document):
@@ -48,6 +48,22 @@ def test_basic2():
     assert Doc.class_name() == 'Doc', Doc.class_name()
     assert Doc.get_collection_name() == 'DocCol'
 
+@raises(DocumentException)
+def bad_extra_fields_param_test():
+    class BadDoc(Document):
+        config_extra_fields = 'blah'
+
+def extra_fields_test():
+    class BadDoc(Document):
+        config_extra_fields = 'ignore'
+    doc_with_extra = {'foo' : [1]}
+    
+    unwrapped = BadDoc.unwrap(doc_with_extra)
+    assert unwrapped.get_extra_fields() == doc_with_extra
+    
+    assert BadDoc.wrap(unwrapped) == doc_with_extra
+
+
 @raises(MissingValueException)
 def test_required_fields():
     class Doc(Document):
